@@ -109,6 +109,12 @@ systemctl enable --now php-fpm
 # Copy Web Files (including dot files)
 rsync -auzvp ./web-files/ /docker/whp/web/
 
+# Copy all release files to /root/whp/ for script access
+echo "Copying release files to /root/whp/..."
+mkdir -p /root/whp
+rsync -auzvp --exclude='web-files/' ./ /root/whp/
+echo "✓ Release files copied to /root/whp/"
+
 # Install ProFTPD package (configuration happens after database setup)
 echo "Installing ProFTPD..."
 dnf install -y proftpd proftpd-mysql
